//
//  mxUtils.h
//  MySQLGUICommon
//
//  Created by Alfredo Kojima on 9/20/04.
//  Copyright 2004 MySQL AB. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#include "myx_public_interface.h"

NSString *MXGetErrorString(MYX_LIB_ERROR error);

void MXRunAlertPanelWithError(NSString *title, NSString *message, MYX_LIB_ERROR error);
void MXRunAlertPanelWithMySQLError(NSString *title, NSString *message, MYSQL *mysql);

NSImage *MXGetImageFromBundle(NSBundle *bundle, NSString *image);

void MXExpandOutline(NSOutlineView *outline, BOOL expandChildren);